import Alert from '@opentinyvue/vue-alert';
import Button from '@opentinyvue/vue-button';
import Modal from '@opentinyvue/vue-modal';
import FileUpload from '@opentinyvue/vue-file-upload';
import Progress from '@opentinyvue/vue-progress';
import Popconfirm from '@opentinyvue/vue-popconfirm';
import { renderless, api } from '@opentinyvue/vue-renderless/pop-upload/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyButton: Button,
    TinyModal: Modal,
    TinyAlert: Alert,
    TinyFileUpload: FileUpload,
    TinyProgress: Progress,
    TinyPopconfirm: Popconfirm
  },
  props: [].concat(props, ["data", "uploadName", "httpRequest", "beforeUpload", "beforeRemove", "size", "dialogTitle", "uploadButtonText", "withCredentials", "submitButtonText", "cancelButtonText", "uploadFileType", "maxUploadFileSize", "accept", "disabled", "multiple", "limit", "headers", "action", "fileList"]),
  emits: ["remove", "progress", "error", "exceed", "success"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-popupload"
  }, [_c("tiny-button", {
    attrs: {
      "size": _vm.size,
      "disabled": _vm.state.disabled
    },
    on: {
      "click": _vm.showDialog
    }
  }, [_vm._v(_vm._s(_vm.state.uploadButtonText))]), _c("tiny-modal", {
    staticClass: "tiny-popupload__modal",
    attrs: {
      "title": _vm.state.dialogTitle,
      "width": "648"
    },
    on: {
      "close": _vm.closeDialog
    },
    model: {
      value: _vm.state.isShowDialog,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "isShowDialog", $$v);
      },
      expression: "state.isShowDialog"
    }
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog"
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog-header"
  }, [_vm._t("uploadTip"), !_vm.slots.uploadTip ? [_vm.state.tipsTitle[0] !== void 0 || _vm.state.tipsTitle[1] !== void 0 || _vm.state.tipsTitle[2] !== void 0 ? _c("tiny-alert", {
    attrs: {
      "size": "large",
      "title": _vm.state.tipsTitleText
    }
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog-tips"
  }, _vm._l(_vm.state.tipsTitle.filter(function(value) {
    return value !== void 0;
  }), function(item, index) {
    return _c("p", {
      key: index,
      staticClass: "tiny-popupload__dialog-tips-item"
    }, [_vm._v(" " + _vm._s(item.count !== void 0 ? _vm.state.limitCountTips + ": " + item.count : "") + " " + _vm._s(item.type !== void 0 ? _vm.state.limitTypeTips + ": " + item.type : "") + " " + _vm._s(item.size !== void 0 ? _vm.state.limitSizeTips + ": " + item.size : "") + " ")]);
  }), 0)]) : _vm._e(), _vm.state.errorTips.length > 0 ? _c("tiny-alert", {
    attrs: {
      "type": "error",
      "size": "large"
    },
    on: {
      "close": _vm.closeErrorTips
    }
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog-tips"
  }, _vm._l(_vm.state.errorTips, function(item, index) {
    return _c("p", {
      key: index,
      staticClass: "tiny-popupload__dialog-tips-item"
    }, [_vm._v(" " + _vm._s(item.size !== void 0 ? item.size + ": " + _vm.state.errorSizeTips : "") + " " + _vm._s(item.type !== void 0 ? item.type + ": " + _vm.state.errorTypeTips : "") + " " + _vm._s(item.num !== void 0 ? _vm.state.errorNumTips : "") + " " + _vm._s(item.error !== void 0 ? _vm.state.uploadErrorTips : "") + " ")]);
  }), 0)]) : _vm._e(), _vm.state.successTips.length > 0 ? _c("tiny-alert", {
    attrs: {
      "type": "success",
      "size": "large"
    },
    on: {
      "close": _vm.closeSuccessTips
    }
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog-tips"
  }, _vm._l(_vm.state.successTips, function(item, index) {
    return _c("p", {
      key: index,
      staticClass: "tiny-popupload__dialog-tips-item"
    }, [_vm._v(" " + _vm._s(item) + "," + _vm._s(_vm.state.uploadSuccessTips) + " ")]);
  }), 0)]) : _vm._e()] : _vm._e()], 2), _c("div", {
    staticClass: "tiny-popupload__dialog-body"
  }, [_c("tiny-file-upload", {
    ref: "upload",
    attrs: {
      "data": _vm.data,
      "http-request": _vm.httpRequest,
      "name": _vm.uploadName,
      "before-upload": _vm.beforeAvatarUpload,
      "with-credentials": _vm.state.withCredentials,
      "multiple": _vm.state.multiple,
      "accept": _vm.state.accept,
      "filters": _vm.state.filters,
      "limit": _vm.limit,
      "headers": _vm.state.headers,
      "action": _vm.state.action,
      "auto-upload": false,
      "re-uploadable": _vm.slots.uploadTip
    },
    on: {
      "change": _vm.fileUploadChange,
      "error": _vm.errorEvent,
      "exceed": _vm.handleExceed,
      "progress": _vm.progressEvent,
      "success": _vm.handleAvatarSuccess
    },
    scopedSlots: _vm._u([{
      key: "trigger",
      fn: function fn() {
        return [_c("tiny-button", [_vm._v(_vm._s(_vm.state.multiple ? _vm.state.uploadsButtonText : _vm.state.uploadButtonText))])];
      },
      proxy: true
    }])
  }), _c("div", {
    staticClass: "tiny-popupload__dialog-table"
  }, [_c("div", {
    staticClass: "tiny-popupload__dialog-table-header"
  }, [_c("p", {
    staticClass: "header-col col1"
  }, [_vm._v(_vm._s(_vm.state.fileName))]), _c("p", {
    staticClass: "header-col col2"
  }, [_vm._v(_vm._s(_vm.state.fileSize))]), _c("p", {
    staticClass: "header-col col3"
  }, [_vm._v(_vm._s(_vm.state.fileStatus))]), _c("p", {
    staticClass: "header-col col4"
  }, [_vm._v(_vm._s(_vm.state.fileWords.operation))])]), _c("div", {
    staticClass: "tiny-popupload__dialog-table-body"
  }, [_c("ul", {
    staticClass: "tiny-popupload__dialog-table-list"
  }, _vm._l(_vm.state.uploadList, function(item, index) {
    return _c("li", {
      key: index,
      staticClass: "tiny-popupload__dialog-table-item"
    }, [_c("p", {
      staticClass: "body-col col1"
    }, [_vm._v(_vm._s(item.name))]), _c("p", {
      staticClass: "body-col col2"
    }, [_vm._v(_vm._s(_vm.formatFileSize(item.size)))]), _c("p", {
      staticClass: "body-col col3"
    }, [_c("span", {
      directives: [{
        name: "show",
        rawName: "v-show",
        value: item.status !== "uploading",
        expression: "item.status !== 'uploading'"
      }],
      class: ["tiny-popupload__status-icon", "tiny-popupload__status-icon-" + item.status]
    }), item.status === "ready" ? _c("span", [_vm._v(_vm._s(_vm.state.fileWords.waitUpload))]) : item.status === "uploading" ? _c("tiny-progress", {
      attrs: {
        "percentage": item.percentage,
        "stroke-width": 4
      }
    }) : item.status === "success" ? _c("span", [_vm._v(_vm._s(_vm.state.fileWords.success))]) : item.status === "fail" ? _c("span", [_vm._v(_vm._s(_vm.state.fileWords.uploadError))]) : _vm._e()], 1), _c("p", {
      staticClass: "body-col col4"
    }, [_c("tiny-popconfirm", {
      attrs: {
        "title": _vm.state.fileWords.confirmDeleteTips,
        "type": "warning",
        "placement": "top-start",
        "trigger": "click",
        "width": "196",
        "custom-class": "tiny-popupload__pop-confirm"
      },
      on: {
        "confirm": function confirm($event) {
          return _vm.deleteFile(item);
        }
      },
      scopedSlots: _vm._u([{
        key: "reference",
        fn: function fn() {
          return [_c("div", {
            staticClass: "del-col"
          }, [_vm._v(_vm._s(_vm.state.fileWords.delete))])];
        },
        proxy: true
      }], null, true)
    })], 1)]);
  }), 0), _vm.slots.uploadTip ? _c("div", {
    staticClass: "tiny-popupload__dialog-table-list-footer"
  }, [_vm._v(" " + _vm._s(_vm.t("ui.popupload.listTip", [_vm.state.uploadList.length]))), _c("span", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.state.errorTips.length > 0,
      expression: "state.errorTips.length > 0"
    }],
    staticClass: "footer-error-tip"
  }, [_vm._v(_vm._s(_vm.t("ui.popupload.errorListTip", [_vm.state.errorTips.length])))])]) : _vm._e()])])], 1), _vm.state.theme === "saas" ? _c("div", {
    staticClass: "tiny-popupload__dialog-footer"
  }, [_c("tiny-button", {
    on: {
      "click": _vm.closeDialog
    }
  }, [_vm._v(_vm._s(_vm.state.cancelButtonText))]), _c("tiny-button", {
    attrs: {
      "type": "primary",
      "disabled": _vm.state.uploadList.length === 0
    },
    on: {
      "click": _vm.uploadSubmit
    }
  }, [_vm._v(_vm._s(_vm.state.submitButtonText))])], 1) : _c("div", {
    staticClass: "tiny-popupload__dialog-footer"
  }, [_c("tiny-button", {
    attrs: {
      "type": "primary",
      "disabled": _vm.state.uploadList.length === 0
    },
    on: {
      "click": _vm.uploadSubmit
    }
  }, [_vm._v(_vm._s(_vm.state.submitButtonText))]), _c("tiny-button", {
    on: {
      "click": _vm.closeDialog
    }
  }, [_vm._v(_vm._s(_vm.state.cancelButtonText))])], 1)])])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
